Learn R Programming

romic (version 1.3.3)

export_tomic_as_wide: Export T*Omic as Wide Data

Description

abundances form a matrix with metabolites as rows and samples as columns. Use transpose to treat samples as rows filename

Usage

export_tomic_as_wide(
  tomic,
  dir_path,
  name_preamble,
  value_var = NULL,
  transpose = FALSE,
  verbose = TRUE
)

Value

Export one table which contains metabolites as rows and samples as columns.

Arguments

tomic

Either a tidy_omic or triple_omic object

dir_path

path to save outputs

name_preamble

start of output file name

value_var

measurement variable to use for the matrix

transpose

if TRUE then samples will be stored as rows. If FALSE (default) then samples will be columns.

verbose

extra reporting messages

Examples

Run this code

if (interactive()) {
  export_tomic_as_wide(brauer_2008_triple, "/tmp", "brauer")
}

Run the code above in your browser using DataLab