Learn R Programming

romic (version 1.3.3)

reform_tidy_omic: Reform Tidy Omic

Description

This function recreates a `tidy_omic` object from the "data" and "design" attributes of this object.

Usage

reform_tidy_omic(tidy_data, tomic_design)

Arguments

tidy_data

A tibble containing measurements along with sample metadata. This table can be obtained as the "data" attribute from a romic "tidy_omic" object.

tomic_design

a list with named attributes describing feature, sample, and measurement variables.

Details

This is handy for passing data and metadata through approaches like parsnip which expect data to be formatted as a data.frame

Examples

Run this code
tidy_data <- romic::brauer_2008_tidy$data
reform_tidy_omic(tidy_data, romic::brauer_2008_tidy$design)

Run the code above in your browser using DataLab