powered by
This function recreates a `tidy_omic` object from the "data" and "design" attributes of this object.
reform_tidy_omic(tidy_data, tomic_design)
A tibble containing measurements along with sample metadata. This table can be obtained as the "data" attribute from a romic "tidy_omic" object.
a list with named attributes describing feature, sample, and measurement variables.
This is handy for passing data and metadata through approaches like parsnip which expect data to be formatted as a data.frame
tidy_data <- romic::brauer_2008_tidy$data reform_tidy_omic(tidy_data, romic::brauer_2008_tidy$design)
Run the code above in your browser using DataLab